---
meta:
    description:
        Redshift cluster

    parameters:
        iam_role_policies:
            description: A list of IAM policies to attach to the cluster role
            value: []

        decrypt_arn:
            description: The ARN of the custom resource providing KMS decryption
            value:

        automated_snapshot_retention_period:
            value:
                0

        availability_zone:
            required: no
            value:

        cluster_security_groups:
            description:
                A list of security groups to associated with the cluster.
            value: []

        subnet_id:
            description:
                The subnet where the RS cluster will be placed.
            value:

        subdomain:
            description:
                The subdomain for the Redshift cluster.
            value:

        domain:
            description:
                The domain for the Redshift cluster.
            value:

        hosted_zone_id:
            description:
                The hosted zone ID for the cluster DNS record.
            value:

        size:
            description:
                The size of the cluster in number of nodes.
            value:
                1

        db_name:
            description:
                The name of the database.
            value:
                {{__context.environment.name.replace('-', '_').replace(' ', '_')}}

        master_username:
            value:
                {{__context.environment.name.replace('-', '_').replace(' ', '_')}}

        master_user_password:
            value:
                {% if env.REDSHIFT_MASTER_USER_PASSWORD %}
                "{{env.REDSHIFT_MASTER_USER_PASSWORD}}"
                {% else %}
                "1{{15|password}}"
                {% endif %}

        node_type:
            description:
                The type of node.
            value:
                dc1.large


        number_of_nodes:
            description:
                The number of nodes in the cluster.
            value:
                1

        vpc_security_group_ids:
            value: []


        sg_whitelist:
            value: []

        ip_whitelist:
            value: []


        vpc_id:
            value:
